﻿using Kivii;
using Kivii.Lims.Entities;
using Kivii.Linq;
using Kivii.Standards.Entities;
using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Domain.Lac.Lims.Extensions
{
    public static class ReportItemExtension
    {
        #region 记录标准值操作日志
        //标准值操作日志
        public static void SetDetectionValueQualifiedLog(this ReportItem reportItem,string type, IDbConnection conn = null, string oldValue=null, string newValue=null,string source=null)
        {
            if (conn == null)
            {
                conn = KiviiContext.GetOpenedDbConnection<ReportItem>();
            }

            var _log = new EntityLog<ReportItem>();
            try
            {
                _log.OwnerKvid = reportItem.Kvid;
                _log.BizId = reportItem.Title;
                _log.BizKvid = reportItem.Kvid;
                _log.BizType = "Kivii.Lac.Lims.Entities.ReportItem";

            }
            catch { }
            _log.Title = "标准值操作日志";
            _log.Type = "OperateDetectionValueQualified";
            _log.Source= source;
            if (type == "create") _log.Summary = "标准值初始值：" + (reportItem.DetectionValueQualified.IsNullOrEmpty() ? "尚未匹配标准值!" : reportItem.DetectionValueQualified);
            if (type == "update") _log.Summary = $"标准值由“{oldValue}”修改为“{newValue}”";
            if (_log.Summary.Length > 500) _log.Summary = _log.Summary.Substring(0, 450) + "···";
            conn.Insert(_log);
        }
        #endregion

        #region 判断当前项目的标准值条件类型
        public static string GetDetectionValueCondition(this ReportItem reportItem,List<DetectionValue> detectionValues)
        {
            //SampleGrade+SampleGradeSafety+SampleGradeFunction+Common(部分条件,不做处理)
            (reportItem == null).ThrowIfTrue("未传入检验项目!");
            if (detectionValues.IsNullOrEmpty()) return "Common";
            var currentDetectionValues = detectionValues.Where(o=>o.DetectionKvid==reportItem.DetectionKvid&&o.ParentKvid==Guid.Empty).ToList();
            if (currentDetectionValues.IsNullOrEmpty()) return "Common";
            var currentDetectionValuesCondition = currentDetectionValues.ConvertAll(o=>o.Condition);
            var sampleGrade = new List<string> { "优等品", "一等品", "合格品", "二等品" };
            var sampleGradeSafety = new List<string> { "A类", "B类", "C类" };
            if (sampleGrade.Any(o => currentDetectionValuesCondition.Contains(o))) return "SampleGrade";
            if (sampleGradeSafety.Any(o => currentDetectionValuesCondition.Contains(o))) return "SampleGradeSafety";
            return "SampleGradeFunction";
        }
        #endregion
    }
}
