﻿using Kivii;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Lac.Lims.RabbitMq.Entities
{
    public class ReportMqRequest
    {
        [ApiMember(Description = "报告编号")]
        public string ReportId { get; set; }
        public Guid Kvid { get; set; }

        [ApiMember(Description = "来源编号")]
        public string SampleSourceBatchNumber { get; set; }

        [ApiMember(Description = "报告类型")]
        public string Type { get; set; }

        /// <summary>
        /// 报告类型后缀
        /// 委托报告(W),监督报告(J)
        /// </summary>
        [ApiMember(Description = "报告类型扩展")]
        public string TypeEx { get; set; }

        /// <summary>
        /// 报告类型名称中文显示
        /// 委托送样，委托抽样
        /// </summary>
        [ApiMember(Description = "报告类型名称")]
        public string TypeName { get; set; }

        /// <summary>
        /// 报告分类，现记录客户编码（报告后缀）UR......
        /// </summary>
        [ApiMember(Description = "报告分类")]
        public string Category { get; set; }

        [ApiMember(Description = "报告份数")]
        public decimal Quantity { get; set; }

        [ApiMember(Description = "供方名称,即检测单位")]
        public string SupplierName { get; set; }

        [ApiMember(Description = "需方名称,即委托单位")]
        public string DemanderName { get; set; }

        [ApiMember(Description = "付款单位,贷方")]
        public string PayerName { get; set; }

        [ApiMember(Description = "收款单位,借方")]
        public string PayeeName { get; set; }

        [ApiMember(Description = "样品名称")]
        public string SampleName { get; set; }

        [ApiMember(Description = "样品批次号")]
        public string SampleBatchNumber { get; set; }

        [ApiMember(Description = "委托日期")]
        public DateTime DealDate { get; set; }

        [ApiMember(Description = "签发日期")]
        public DateTime? IssueDate { get; set; }

        [ApiMember(Description = "要求完成日期")]
        public DateTime DeadDate { get; set; }

        /// <summary>
        /// 签发人Kvid
        /// </summary>
        public Guid IssuerKvid { get; set; }

        /// <summary>
        /// 签发人姓名
        /// </summary>
        [ApiMember(Description = "签发人")]
        public string IssuerName { get; set; }

        /// <summary>
        /// 产品质量综合判定
        /// </summary>
        [ApiMember(Description = "产品质量综合判定")]
        public string TestJudgement { get; set; }

        /// <summary>
        /// 检验结论，报告的结论
        /// </summary>
        [ApiMember(Description = "检验结论")]
        public string Conclusion { get; set; }

        public Dictionary<string, string> Metadata { get; set; }

        /// <summary>
        /// 这个用于Pdf/Stamper的InternalCode
        /// 默认 中文签章
        /// </summary>
        public string Stamp { get; set; } = "新中文印章";

        /// <summary>
        /// 上传PDF的路径
        /// 一般格式:/Storages/{存储路径}/{OwnerKvid}/{文件名(带后缀)}
        /// 例子:/Storages/Reports/Pdf/{entity.ContractKvid}/{entity.ReportId}.pdf
        /// </summary>
        public string SaveFilePath { get; set; }

        /// <summary>
        /// 下载Excel的路径
        /// 一般格式:/Storages/{存储路径}/{OwnerKvid}/{文件名(带后缀)}
        /// 例子:/Storages/Report/Excel01/{entity.ContractKvid}/{entity.ReportId}.xlsx
        /// </summary>
        public string OpenFilePath { get; set; }
    }
}
